;LOGIC PROBE
;Program for PIC12c508A

Start   ORG 0x00	
	MOVLW 08	;Put 08 into W  (GP3 can only be input)
	TRIS 06		;to make GP3 input, others output	
	CLRF 06		;Clear port 6
	CLRF 11h	;Clear 1 minute alarm file
	GOTO Main


Alarm	MOVLW 20h	;Length of the alarm
	MOVWF 12h
Alarm1	MOVLW 40h	;The HIGH/LOW time
	MOVWF 13h
Alarm2	DECFSZ 13h,1	;Time for ON and OFF periods
	GOTO Alarm2	
	MOVLW 20h	;Toggle the Piezo line
	XORWF 06,1
	DECFSZ 14,1	;256 loops of ON/OFF
	GOTO Alarm1
	DECFSZ 12h,1
	GOTO Alarm1
	CLRF 11h	;Clear the alarm 1-minute timer file
	BCF 06,5	;Turn off piezo bit
	RETURN




		
Delay	MOVLW 05	;5 loops of routine below
	MOVWF 0E	;
Delay1	MOVLW 0B0h	;Create the 1/4sec ON period
	MOVWF 0Dh
Delay2	CALL Input
	CALL TstA
	DECFSZ 0Dh,1	;Loop for 0B loops to create 1/4 sec
	GOTO Delay2
	DECFSZ 0Eh,1	;Loop 5 lots of 0B loops
	GOTO Delay1
	RETURN
	

			;The "Input" sub-routine will put a 
			;value in files 1E and 1F

Input	CLRF 1E		;Clear the HIGH count file
	CLRF 1F		;Clear the LOW count file
	MOVLW 08h	;8 loops
	MOVWF 0Ch	;C is 8 for 8 loops
Input1	BSF 06,4	;Make probe Tip HIGH
	NOP
	NOP
	NOP		;Allow time for 47p to charge
	NOP
	BTFSS 06,3	;Test the input line RB3
	GOTO Input2	;Input is LOW
	INCF 1E,1	;Increment the HIGH file
	GOTO Input3
Input2  INCF 1F,1	;Increment the LOW file
Input3	BCF 06,4	;Make probe tip LOW
	NOP
	NOP
	NOP
	NOP
	NOP		;Allow time for 47p to discharge
	NOP
	MOVLW 05
	MOVWF 13h
Input4	BTFSC 06,3	;Test the input line RB3
	GOTO Input5
	DECFSZ 13h,1
	GOTO Input4
	INCF 1F,1	;Increment the LOW file
	GOTO Input6
Input5	INCF 1E,1	;Increment the HIGH file	
Input6	DECFSZ 0Ch,1
	GOTO Input1
	BCF 06,0	;Turn off LOW LED
	BCF 06,1	;Turn off HIGH LED
	RETURN
	
	;This routine checks to see if file 1E is zero		
	;   if not, it does a subtraction with W to 
	;   see if it is 1, 2 or 3. This indicates a pulse!
	;The routine then checks for a constant HIGH or LOW
				
TstA	MOVLW 00h	;Eliminate file 1E if it is zero
	XORWF 1E,0	;XOR file 1E with W
	BTFSC 03,2 	;Test the zero flag to see if file 1E is zero
	GOTO TstA1	;File 1E is zero
	MOVLW 04	;Put 04 into W for subtract operation
	SUBWF 1E,0	;Carry will be set if 1E is = or more than 4
	BTFSS 03,0	;Test the carry flag 
	GOTO Hi		;Will go to Hi if 1E is 1, 2, or 3

TstA1	MOVLW 00h	;This tests if the waveform is never LOW
	XORWF 1F,0	;   - it must be HIGH
	BTFSC 03,2	;Test zero bit in Option file
	GOTO Hi
	MOVLW 00h	;This tests if the waveform is never LOW
	XORWF 1E,0	;
	BTFSC 03,2	;Zero flag in Option file will be set
	GOTO Lo		;    if 1E is equal to zero
	RETURN		;
	


Hi	MOVLW 40h	;Length of Hi tone
	MOVWF 1A
	BSF 06,1	;Turn on HIGH LED
	GOTO Tone

Lo	BSF 06,0	;Turn on LOW LED
	GOTO Tone
	
	
Tone	DECFSZ 1A,1
	GOTO Tone	
	MOVLW 20h	
	XORWF 06,1	;Toggle the piezo bit	
	CLRF 11h	;Clear the 1 minute alarm file
	RETURN

	
Main	BSF 06,2	;Set the Pulser output HIGH
	CALL Delay
	BCF 06,2	;Set the pulser output LOW
	CALL Delay
	MOVLW 05	;5 loops for file 0E
	MOVWF 0E
Main1	MOVLW 0B0h	;B0 loops for file 0D
	MOVWF 0D
Main2	MOVLW 04h	;toggle the Logic Pulser output RB2
	XORWF 06,1
	CALL Input
	CALL TstA
	DECFSZ 0Dh,1	;B0 loops
	GOTO Main2
	DECFSZ 0Eh,1	;5 lots of B0 loops
	GOTO Main1
	BCF 06,2	;Set the Pulser output LOW
	CALL Delay
	INCF 11h,1	;increment the 1 minute alarm file
	MOVLW 40h	;40h = 64 loops of 1 second = 1 minute
	XORWF 11h,0	;Is alarm file =zero
	BTFSC 03,2	;Test the zero flag
	CALL Alarm	;"turn off Logic Probe" beep
        BSF 03,5	;Go to page1 for setting-up the ports	
	BCF 06,5	;Set RB5 to output
	BCF 03,5	;Go to page0 for programming
	BCF 06,5	;Turn off piezo bit
	GOTO Main

	END

	
		